@@ -23,7 +23,10 @@
   #include <windows.h>
 #endif
 #include <gz/math/Helpers.hh>
+#include <gz/math/Matrix4.hh>
+
 #include "gz/rendering/InstallationDirectories.hh"
+#include "gz/rendering/ogre/OgreConversions.hh"
 #include "gz/rendering/ogre/OgreDepthCamera.hh"
 #include "gz/rendering/ogre/OgreMaterial.hh"
 
@@ -224,19 +227,6 @@ void OgreDepthCamera::CreatePointCloudTexture()
 
   const char *env = std::getenv("GZ_RENDERING_RESOURCE_PATH");
 
-  // TODO(CH3): Deprecated. Remove on tock.
-  if (!env)
-  {
-    env = std::getenv("IGN_RENDERING_RESOURCE_PATH");
-
-    if (env)
-    {
-      gzwarn << "Using deprecated environment variable "
-             << "[IGN_RENDERING_RESOURCE_PATH]. Please use "
-             << "[GZ_RENDERING_RESOURCE_PATH] instead." << std::endl;
-    }
-  }
-
   std::string resourcePath = (env) ? std::string(env) :
       gz::rendering::getResourcePath();
 
@@ -312,6 +302,18 @@ void OgreDepthCamera::DestroyDepthTexture()
   }
 }
 
+/////////////////////////////////////////////////
+math::Matrix4d OgreDepthCamera::ProjectionMatrix() const {
+  return OgreConversions::Convert(this->ogreCamera->getProjectionMatrix());
+}
+
+/////////////////////////////////////////////////
+void OgreDepthCamera::SetProjectionMatrix(const math::Matrix4d &_matrix) {
+  BaseDepthCamera::SetProjectionMatrix(_matrix);
+  this->ogreCamera->setCustomProjectionMatrix(
+      true, OgreConversions::Convert(this->projectionMatrix));
+}
+
 //////////////////////////////////////////////////
 void OgreDepthCamera::PreRender()
 {
