@@ -19,6 +19,14 @@
 #if !defined(__APPLE__) && !defined(_WIN32)
 # include <X11/Xlib.h>
 # include <X11/Xutil.h>
+
+// conda-forge's glext.h is old and has a bug.
+// This is a minimally-intrusive fix to correct types.
+// On modern GL distributions, glx.h will override these.
+# include <KHR/khrplatform.h>
+typedef khronos_ssize_t GLsizeiptr;
+typedef khronos_intptr_t GLintptr;
+
 # include <GL/glx.h>
 #endif
 
@@ -28,8 +36,12 @@
   #include <Winsock2.h>
 #endif
 
+#include <dlfcn.h>
+
 # include <sstream>
 
+#include <OgreDynLib.h>
+
 #include <gz/plugin/Register.hh>
 
 #include <gz/common/Console.hh>
@@ -58,6 +70,32 @@ class gz::rendering::OgreRenderEnginePrivate
 using namespace gz;
 using namespace rendering;
 
+// Unloading the RenderSystem_GL plugin was found to cause a crash when the
+// rendering thread exits. This only happens on Ubuntu 24.04 when running
+// ogre using system debs, see
+// https://github.com/gazebosim/gz-rendering/issues/1007
+// To workaround ths issue, we adapt the code for loading the ogre plugin here.
+// We load the RenderSystem_GL library manually and store it in gz-rendering.
+// On shutdown, ogre root will uninstall this plugin and delete the GL
+// render system objects. However, gz-rendering does not unload this plugin.
+// \todo(iche033) Find a proper way to unload the library without causing a
+// crash.
+typedef void (*DLL_START_PLUGIN)(void);
+DYNLIB_HANDLE glPluginHandle;
+
+void loadGLPlugin(const std::string &_pluginName)
+{
+#ifdef _WIN32
+  glPluginHandle = DYNLIB_LOAD(_pluginName.c_str());
+#else
+  glPluginHandle = dlopen(_pluginName.c_str(), RTLD_LAZY | RTLD_LOCAL);
+#endif
+  DLL_START_PLUGIN pFunc = (DLL_START_PLUGIN)DYNLIB_GETSYM(
+      glPluginHandle, "dllStartPlugin");
+  pFunc();
+  return;
+}
+
 //////////////////////////////////////////////////
 OgreRenderEnginePlugin::OgreRenderEnginePlugin()
 {
@@ -110,9 +148,9 @@ void OgreRenderEngine::Destroy()
 
   if (ogreRoot)
   {
+    // TODO(anyone): do we need to catch segfault on delete?
     try
     {
-      // TODO(anyone): do we need to catch segfault on delete?
       delete this->ogreRoot;
     }
     catch (...)
@@ -450,17 +488,26 @@ void OgreRenderEngine::LoadPlugins()
 
     for (piter = plugins.begin(); piter != plugins.end(); ++piter)
     {
+
+      bool isGLPlugin = std::string(*piter).find("RenderSystem_GL")
+          != std::string::npos;
       try
       {
-        // Load the plugin into OGRE
-        this->ogreRoot->loadPlugin(*piter+extension);
+        // Load the plugin
+        if (isGLPlugin)
+          loadGLPlugin(*piter+extension);
+        else
+          this->ogreRoot->loadPlugin(*piter+extension);
       }
       catch(Ogre::Exception &e)
       {
         try
         {
-          // Load the debug plugin into OGRE
-          this->ogreRoot->loadPlugin(*piter+"_d"+extension);
+          // Load the debug plugin
+          if (isGLPlugin)
+            loadGLPlugin(*piter+"_d"+extension);
+          else
+            this->ogreRoot->loadPlugin(*piter+"_d"+extension);
         }
         catch(Ogre::Exception &ed)
         {
@@ -479,6 +526,7 @@ void OgreRenderEngine::LoadPlugins()
 //////////////////////////////////////////////////
 void OgreRenderEngine::CreateRenderSystem()
 {
+  Ogre::RenderSystem *renderSys;
   const Ogre::RenderSystemList *rsList;
 
   // Set parameters of render system (window size, etc.)
@@ -490,7 +538,7 @@ void OgreRenderEngine::CreateRenderSystem()
 
   int c = 0;
 
-  Ogre::RenderSystem *renderSys = nullptr;
+  renderSys = nullptr;
 
   do
   {
@@ -511,7 +559,6 @@ void OgreRenderEngine::CreateRenderSystem()
     gzerr << "unable to find OpenGL rendering system. OGRE is probably "
             "installed incorrectly. Double check the OGRE cmake output, "
             "and make sure OpenGL is enabled." << std::endl;
-    return;
   }
 
   // We operate in windowed mode
@@ -569,19 +616,6 @@ void OgreRenderEngine::CreateResources()
   std::list<std::string> paths;
   const char *env = std::getenv("GZ_RENDERING_RESOURCE_PATH");
 
-  // TODO(CH3): Deprecated. Remove on tock.
-  if (!env)
-  {
-    env = std::getenv("IGN_RENDERING_RESOURCE_PATH");
-
-    if (env)
-    {
-      gzwarn << "Using deprecated environment variable "
-             << "[IGN_RENDERING_RESOURCE_PATH]. Please use "
-             << "[GZ_RENDERING_RESOURCE_PATH] instead." << std::endl;
-    }
-  }
-
   std::string resourcePath = (env) ? std::string(env) :
       gz::rendering::getResourcePath();
   // install path
@@ -653,6 +687,7 @@ std::string OgreRenderEngine::CreateRenderWindow(const std::string &_handle,
     // Mac and Windows *must* use externalWindow handle.
 #if defined(__APPLE__) || defined(_MSC_VER)
     params["externalWindowHandle"] = _handle;
+    params["hidden"] = "true";
 #else
     params["parentWindowHandle"] = _handle;
 #endif
