@@ -35,6 +35,7 @@
 #include "gz/rendering/ogre/OgreInertiaVisual.hh"
 #include "gz/rendering/ogre/OgreJointVisual.hh"
 #include "gz/rendering/ogre/OgreLidarVisual.hh"
+#include "gz/rendering/ogre/OgreFrustumVisual.hh"
 #include "gz/rendering/ogre/OgreLightVisual.hh"
 #include "gz/rendering/ogre/OgreMarker.hh"
 #include "gz/rendering/ogre/OgreMaterial.hh"
@@ -622,6 +623,15 @@ LidarVisualPtr OgreScene::CreateLidarVisualImpl(unsigned int _id,
   return (result) ? lidar: nullptr;
 }
 
+//////////////////////////////////////////////////
+FrustumVisualPtr OgreScene::CreateFrustumVisualImpl(unsigned int _id,
+                                      const std::string &_name)
+{
+  OgreFrustumVisualPtr frustum(new OgreFrustumVisual);
+  bool result = this->InitObject(frustum, _id, _name);
+  return (result) ? frustum: nullptr;
+}
+
 //////////////////////////////////////////////////
 TextPtr OgreScene::CreateTextImpl(unsigned int _id, const std::string &_name)
 {
@@ -771,7 +781,7 @@ OgreSceneExt::OgreSceneExt(Scene *_scene)
 ObjectPtr OgreSceneExt::CreateExt(const std::string &_type,
       const std::string &_name)
 {
-  if (_type == "projector")
+  if (_type == "frustum_visual")
   {
     OgreScene *ogreScene = dynamic_cast<OgreScene *>(this->scene);
     unsigned int objId = ogreScene->CreateObjectId();
@@ -779,14 +789,14 @@ ObjectPtr OgreSceneExt::CreateExt(const std::string &_type,
     if (objName.empty())
     {
       std::stringstream ss;
-      ss << ogreScene->Name() << "::" <<  "Projector";
+      ss << ogreScene->Name() << "::" <<  "FrustumVisual";
       ss << "(" << std::to_string(objId) << ")";
       objName = ss.str();
     }
-    ProjectorPtr projector = ogreScene->CreateProjectorImpl(
+    FrustumVisualPtr frustumVisual = ogreScene->CreateFrustumVisualImpl(
         objId, objName);
-    bool result = ogreScene->Visuals()->Add(projector);
-    return (result) ? projector : nullptr;
+    bool result = ogreScene->Visuals()->Add(frustumVisual);
+    return (result) ? frustumVisual : nullptr;
   }
 
   return ObjectPtr();
