@@ -76,7 +76,7 @@ class Ogre2DepthGaussianNoisePass : public Ogre2GaussianNoisePass
   public: virtual ~Ogre2DepthGaussianNoisePass() {}
 
   // Documentation inherited.
-  public: void PreRender() override;
+  public: virtual void PreRender(const CameraPtr &_camera) override;
 
   // Documentation inherited.
   public: void CreateRenderPass() override;
@@ -180,7 +180,7 @@ using namespace gz;
 using namespace rendering;
 
 //////////////////////////////////////////////////
-void Ogre2DepthGaussianNoisePass::PreRender()
+void Ogre2DepthGaussianNoisePass::PreRender(const CameraPtr &/*_camera*/)
 {
   // This function is similar to Ogre2GaussianNoisePass but duplicated here
   // for Ogre2DepthCamera
@@ -1012,6 +1012,20 @@ void Ogre2DepthCamera::CreateWorkspaceInstance()
   }
 }
 
+/////////////////////////////////////////////////
+math::Matrix4d Ogre2DepthCamera::ProjectionMatrix() const
+{
+  return Ogre2Conversions::Convert(this->ogreCamera->getProjectionMatrix());
+}
+
+/////////////////////////////////////////////////
+void Ogre2DepthCamera::SetProjectionMatrix(const math::Matrix4d &_matrix)
+{
+  BaseDepthCamera::SetProjectionMatrix(_matrix);
+  this->ogreCamera->setCustomProjectionMatrix(
+      true, Ogre2Conversions::Convert(this->projectionMatrix));
+}
+
 //////////////////////////////////////////////////
 void Ogre2DepthCamera::Render()
 {
@@ -1049,20 +1063,6 @@ void Ogre2DepthCamera::PreRender()
   if (!this->dataPtr->ogreCompositorWorkspace)
     this->CreateWorkspaceInstance();
 
-  // todo(iche033) Override BaseCamera::SetProjectionMatrix() function in
-  // main / gz-rendering9 instead of checking and setting the custom
-  // projection matrix here
-  if (this->ogreCamera &&
-      this->projectionMatrix != gz::math::Matrix4d::Zero)
-  {
-    if (this->projectionMatrix !=
-        Ogre2Conversions::Convert(this->ogreCamera->getProjectionMatrix()))
-    {
-      this->ogreCamera->setCustomProjectionMatrix(true,
-          Ogre2Conversions::Convert(this->projectionMatrix));
-    }
-  }
-
   // Disable color target (set to clear pass) if there are no rgb point cloud
   // connections
   if (this->dataPtr->colorTargetDef)
