@@ -483,7 +483,7 @@ bool Ogre2RenderEngine::InitImpl()
   {
     gzerr << "Failed to initialize render-engine" << std::endl;
     gzerr << "Please see the troubleshooting page for possible fixes: "
-          << "https://gazebosim.org/docs/fortress/troubleshooting"
+          << "https://gazebosim.org/docs/latest/troubleshooting"
           << std::endl;
     return false;
   }
@@ -876,19 +876,6 @@ void Ogre2RenderEngine::RegisterHlms()
 {
   const char *env = std::getenv("GZ_RENDERING_RESOURCE_PATH");
 
-  // TODO(CH3): Deprecated. Remove on tock.
-  if (!env)
-  {
-    env = std::getenv("IGN_RENDERING_RESOURCE_PATH");
-
-    if (env)
-    {
-      gzwarn << "Using deprecated environment variable "
-             << "[IGN_RENDERING_RESOURCE_PATH]. Please use "
-             << "[GZ_RENDERING_RESOURCE_PATH] instead." << std::endl;
-    }
-  }
-
   std::string resourcePath = (env) ? std::string(env) :
       gz::rendering::getResourcePath();
 
@@ -1080,19 +1067,6 @@ void Ogre2RenderEngine::CreateResources()
 {
   const char *env = std::getenv("GZ_RENDERING_RESOURCE_PATH");
 
-  // TODO(CH3): Deprecated. Remove on tock.
-  if (!env)
-  {
-    env = std::getenv("IGN_RENDERING_RESOURCE_PATH");
-
-    if (env)
-    {
-      gzwarn << "Using deprecated environment variable "
-             << "[IGN_RENDERING_RESOURCE_PATH]. Please use "
-             << "[GZ_RENDERING_RESOURCE_PATH] instead." << std::endl;
-    }
-  }
-
   std::string resourcePath = (env) ? std::string(env) :
       gz::rendering::getResourcePath();
   // install path
@@ -1222,6 +1196,7 @@ std::string Ogre2RenderEngine::CreateRenderWindow(const std::string &_handle,
       // Mac and Windows *must* use externalWindow handle.
 #if defined(__APPLE__) || defined(_MSC_VER)
       params["externalWindowHandle"] = _handle;
+      params["hidden"] = "true";
 #else
       params["parentWindowHandle"] = _handle;
 #endif
@@ -1434,12 +1409,6 @@ std::vector<unsigned int> Ogre2RenderEngine::FSAALevels() const
   return this->dataPtr->fsaaLevels;
 }
 
-/////////////////////////////////////////////////
-Ogre2GzHlmsSphericalClipMinDistance& Ogre2RenderEngine::HlmsCustomizations()
-{
-  return this->dataPtr->sphericalClipMinDistance;
-}
-
 /////////////////////////////////////////////////
 Ogre2GzHlmsSphericalClipMinDistance& Ogre2RenderEngine::
 SphericalClipMinDistance()
