@@ -281,17 +281,17 @@ void Ogre2ThermalCameraMaterialSwitcher::cameraPreRenderScene(
       {
         float temp = -1.0f;
         bool foundTemp = true;
-        if (std::holds_alternative<float>(tempAny))
+        if (const float* floatPtr = std::get_if<float>(&tempAny))
         {
-          temp = std::get<float>(tempAny);
+          temp = *floatPtr;
         }
-        else if (std::holds_alternative<double>(tempAny))
+        else if (const double* doublePtr = std::get_if<double>(&tempAny))
         {
-          temp = static_cast<float>(std::get<double>(tempAny));
+          temp = static_cast<float>(*doublePtr);
         }
-        else if (std::holds_alternative<int>(tempAny))
+        else if (const int* intPtr = std::get_if<int>(&tempAny))
         {
-          temp = static_cast<float>(std::get<int>(tempAny));
+          temp = static_cast<float>(*intPtr);
         }
         else
         {
@@ -335,7 +335,7 @@ void Ogre2ThermalCameraMaterialSwitcher::cameraPreRenderScene(
             //
             // material may be a nullptr if we called setMaterial directly
             // (i.e. it's not using Ogre2Material interface).
-            // In those cases we fallback to PBS in the current IORM mode.
+            // In those cases we fallback to PBS in the current GORM mode.
             auto material = Ogre::MaterialManager::getSingleton().getByName(
               subItem->getMaterial()->getName() + "_solid",
               Ogre::ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME);
@@ -498,7 +498,7 @@ void Ogre2ThermalCameraMaterialSwitcher::cameraPreRenderScene(
             //
             // material may be a nullptr if we called setMaterial directly
             // (i.e. it's not using Ogre2Material interface).
-            // In those cases we fallback to PBS in the current IORM mode.
+            // In those cases we fallback to PBS in the current GORM mode.
             auto material = Ogre::MaterialManager::getSingleton().getByName(
               subItem->getMaterial()->getName() + "_solid",
               Ogre::ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME);
@@ -554,17 +554,17 @@ void Ogre2ThermalCameraMaterialSwitcher::cameraPreRenderScene(
       {
         float temp = -1.0;
         bool foundTemp = true;
-        if (std::holds_alternative<float>(tempAny))
+        if (const float* floatPtr = std::get_if<float>(&tempAny))
         {
-          temp = std::get<float>(tempAny);
+          temp = *floatPtr;
         }
-        else if (std::holds_alternative<double>(tempAny))
+        else if (const double* doublePtr = std::get_if<double>(&tempAny))
         {
-          temp = static_cast<float>(std::get<double>(tempAny));
+          temp = static_cast<float>(*doublePtr);
         }
-        else if (std::holds_alternative<int>(tempAny))
+        else if (const int* intPtr = std::get_if<int>(&tempAny))
         {
-          temp = static_cast<float>(std::get<int>(tempAny));
+          temp = static_cast<float>(*intPtr);
         }
         else
         {
@@ -1119,35 +1119,6 @@ void Ogre2ThermalCamera::PreRender()
 {
   if (!this->dataPtr->ogreThermalTexture)
     this->CreateThermalTexture();
-
-  // ensure that certain shader constants are up-to-date so that changes that
-  // users can make to the settings show up in the thermal result immediately
-  Ogre::Pass *pass =
-      this->dataPtr->thermalMaterial->getTechnique(0)->getPass(0);
-  Ogre::GpuProgramParametersSharedPtr psParams =
-      pass->getFragmentProgramParameters();
-  psParams->setNamedConstant("max",
-      static_cast<float>(this->maxTemp));
-  psParams->setNamedConstant("min",
-      static_cast<float>(this->minTemp));
-  psParams->setNamedConstant("resolution",
-      static_cast<float>(this->resolution));
-
-  this->dataPtr->thermalMaterialSwitcher->SetLinearResolution(this->resolution);
-
-  // todo(iche033) Override BaseCamera::SetProjectionMatrix() function in
-  // main / gz-rendering9 instead of checking and setting the custom
-  // projection matrix here
-  if (this->ogreCamera &&
-      this->projectionMatrix != gz::math::Matrix4d::Zero)
-  {
-    if (this->projectionMatrix !=
-        Ogre2Conversions::Convert(this->ogreCamera->getProjectionMatrix()))
-    {
-      this->ogreCamera->setCustomProjectionMatrix(true,
-          Ogre2Conversions::Convert(this->projectionMatrix));
-    }
-  }
 }
 
 //////////////////////////////////////////////////
@@ -1239,3 +1210,17 @@ Ogre::Camera *Ogre2ThermalCamera::OgreCamera() const
 {
   return this->ogreCamera;
 }
+
+/////////////////////////////////////////////////
+math::Matrix4d Ogre2ThermalCamera::ProjectionMatrix() const
+{
+  return Ogre2Conversions::Convert(this->ogreCamera->getProjectionMatrix());
+}
+
+/////////////////////////////////////////////////
+void Ogre2ThermalCamera::SetProjectionMatrix(const math::Matrix4d &_matrix)
+{
+  BaseThermalCamera::SetProjectionMatrix(_matrix);
+  this->ogreCamera->setCustomProjectionMatrix(
+      true, Ogre2Conversions::Convert(this->projectionMatrix));
+}
