@@ -95,10 +95,6 @@ class gz::rendering::RenderEngineManagerPrivate
   /// \brief Plugin loader for managing render engine plugin libraries.
   public: gz::plugin::Loader pluginLoader;
 
-  /// \brief Deprecated environment variable which holds paths to look for
-  /// plugins
-  public: std::string pluginPathEnvDeprecated = "IGN_RENDERING_PLUGIN_PATH";
-
   /// \brief Environment variable which holds paths to look for plugins
   public: std::string pluginPathEnv = "GZ_RENDERING_PLUGIN_PATH";
 
@@ -487,23 +483,9 @@ bool RenderEngineManagerPrivate::LoadEnginePlugin(
   auto pathToLib = systemPaths.FindSharedLibrary(_filename);
   if (pathToLib.empty())
   {
-    // Try deprecated environment variable
-    common::SystemPaths systemPathsDep;
-    systemPathsDep.SetPluginPathEnv(this->pluginPathEnvDeprecated);
-    pathToLib = systemPathsDep.FindSharedLibrary(_filename);
-    if (pathToLib.empty())
-    {
-      gzerr << "Failed to load plugin [" << _filename <<
-               "] : couldn't find shared library." << std::endl;
-      return false;
-    }
-    else
-    {
-      gzwarn << "Found plugin [" << _filename
-             << "] using deprecated environment variable ["
-             << this->pluginPathEnvDeprecated << "]. Please use ["
-             << this->pluginPathEnv << "] instead." << std::endl;
-    }
+    gzerr << "Failed to load plugin [" << _filename <<
+             "] : couldn't find shared library." << std::endl;
+    return false;
   }
 
   // Load plugin
@@ -593,14 +575,10 @@ bool RenderEngineManagerPrivate::UnloadEnginePlugin(
   std::string pluginName = it->second;
   this->enginePlugins.erase(it);
 
-#ifndef _WIN32
-  // Unloading the plugin on windows causes tests to crash on exit
-  // see issue #45
   if (!this->pluginLoader.ForgetLibraryOfPlugin(pluginName))
   {
     gzerr << "Failed to unload plugin: " << pluginName << std::endl;
   }
-#endif
 
   std::lock_guard<std::recursive_mutex> lock(this->enginesMutex);
   auto engineIt = this->engines.find(_engineName);
