@@ -30,6 +30,7 @@
 #include "gz/rendering/InstallationDirectories.hh"
 #include "gz/rendering/JointVisual.hh"
 #include "gz/rendering/LidarVisual.hh"
+#include "gz/rendering/FrustumVisual.hh"
 #include "gz/rendering/LightVisual.hh"
 #include "gz/rendering/Camera.hh"
 #include "gz/rendering/Capsule.hh"
@@ -1262,6 +1263,38 @@ LidarVisualPtr BaseScene::CreateLidarVisual(unsigned int _id,
   return (result) ? lidar : nullptr;
 }
 
+// \todo(iche033) Commented out for ABI compatibility. Uncomment in
+// gz-rendering10
+// //////////////////////////////////////////////////
+// FrustumVisualPtr BaseScene::CreateFrustumVisual()
+// {
+//   unsigned int objId = this->CreateObjectId();
+//   return this->CreateFrustumVisual(objId);
+// }
+//
+// //////////////////////////////////////////////////
+// FrustumVisualPtr BaseScene::CreateFrustumVisual(unsigned int _id)
+// {
+//   const std::string objName = this->CreateObjectName(_id, "FrustumVisual");
+//   return this->CreateFrustumVisual(_id, objName);
+// }
+//
+// //////////////////////////////////////////////////
+// FrustumVisualPtr BaseScene::CreateFrustumVisual(const std::string &_name)
+// {
+//   unsigned int objId = this->CreateObjectId();
+//   return this->CreateFrustumVisual(objId, _name);
+// }
+//
+// //////////////////////////////////////////////////
+// FrustumVisualPtr BaseScene::CreateFrustumVisual(unsigned int _id,
+//                                             const std::string &_name)
+// {
+//   FrustumVisualPtr frustum = this->CreateFrustumVisualImpl(_id, _name);
+//   bool result = this->RegisterVisual(frustum);
+//   return (result) ? frustum : nullptr;
+// }
+
 //////////////////////////////////////////////////
 WireBoxPtr BaseScene::CreateWireBox()
 {
@@ -1475,6 +1508,29 @@ bool BaseScene::SkyEnabled() const
   return false;
 }
 
+//////////////////////////////////////////////////
+bool BaseScene::SetShadowTextureSize(LightType _lightType,
+    unsigned int _textureSize)
+{
+  if (static_cast<int>(_lightType) || _textureSize)
+  {
+    gzerr << "Setting shadow texture size not supported by: "
+          << this->Engine()->Name() << std::endl;
+  }
+  return false;
+}
+
+//////////////////////////////////////////////////
+unsigned int BaseScene::ShadowTextureSize(LightType _lightType) const
+{
+  if (static_cast<int>(_lightType))
+  {
+    gzerr << "Shadow texture size not supported by: "
+          << this->Engine()->Name() << std::endl;
+  }
+  return 0;
+}
+
 //////////////////////////////////////////////////
 void BaseScene::SetActiveGlobalIllumination(GlobalIlluminationBasePtr _gi)
 {
@@ -1655,20 +1711,6 @@ void BaseScene::CreateMaterials()
   material->SetLightingEnabled(true);
 
   const char *env = std::getenv("GZ_RENDERING_RESOURCE_PATH");
-
-  // TODO(CH3): Deprecated. Remove on tock.
-  if (!env)
-  {
-    env = std::getenv("IGN_RENDERING_RESOURCE_PATH");
-
-    if (env)
-    {
-      gzwarn << "Using deprecated environment variable "
-             << "[IGN_RENDERING_RESOURCE_PATH]. Please use "
-             << "[GZ_RENDERING_RESOURCE_PATH] instead." << std::endl;
-    }
-  }
-
   std::string resourcePath = (env) ? std::string(env) :
       gz::rendering::getResourcePath();
 
